# `unxt` library

```{toctree}
:maxdepth: 1
:caption: API submodules
:glob:

dims.md
units.md
unitsystems.md
quantity.md
*
```

---

```{eval-rst}

.. currentmodule:: unxt

.. automodule:: unxt
    :exclude-members: aval, default, materialise, enable_materialise
    :noindex:

```
